==> org.apache.aries.jmx.core-1.0.1-source-release.zip: org.apache.aries.jmx.core-1.0.1/src/test/java/org/apache/aries/jmx/framework/ServiceStateMBeanHandlerTest.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.aries.jmx.framework;

import static org.junit.Assert.*;
import static org.mockito.Mockito.*;

import org.apache.aries.jmx.Logger;
import org.junit.Test;
import org.osgi.framework.BundleContext;

/**
 * 
 *
 * @version $Rev: 896239 $ $Date: 2010-01-05 23:02:23 +0100 (Tue, 05 Jan 2010) $
 */
public class ServiceStateMBeanHandlerTest {

   
    @Test
    public void testOpen() throws Exception {
        
        BundleContext context = mock(BundleContext.class);
        Logger logger = mock(Logger.class);
        
        ServiceStateMBeanHandler handler = new ServiceStateMBeanHandler(context, logger);
        handler.open();
        
        assertNotNull(handler.getMbean());
        
    }

}

==> org.apache.aries.jmx.core-1.1.0-source-release.zip: org.apache.aries.jmx.core-1.1.0/src/test/java/org/apache/aries/jmx/framework/ServiceStateMBeanHandlerTest.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.aries.jmx.framework;

import static org.junit.Assert.assertNotNull;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.apache.aries.jmx.Logger;
import org.junit.Test;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.Constants;

/**
 *
 *
 * @version $Rev: 1222658 $ $Date: 2011-12-23 07:36:15 -0500 (Fri, 23 Dec 2011) $
 */
public class ServiceStateMBeanHandlerTest {


    @Test
    public void testOpen() throws Exception {

        BundleContext context = mock(BundleContext.class);
        when(context.getProperty(Constants.FRAMEWORK_UUID)).thenReturn("some-uuid");

        Logger logger = mock(Logger.class);

        Bundle mockSystemBundle = mock(Bundle.class);
        when(mockSystemBundle.getSymbolicName()).thenReturn("the.sytem.bundle");
        when(context.getBundle(0)).thenReturn(mockSystemBundle);

        ServiceStateMBeanHandler handler = new ServiceStateMBeanHandler(context, logger);
        handler.open();

        assertNotNull(handler.getMbean());

    }

}
